Crate farmsim

Crate farmsim 

Modules

utils

Structs

CareerSavegame
CsgMod
CsgStatistics
DssData
DssMod
DssPlayer
Note: The xyz coordinates are only visible when player is on foot!
Economy
Endpoint
EndpointBuilder
Environment
Farm
FarmPlayer
FarmStatistics
Farmland
Farms
Field
FillType
FillTypes
Finances
GreatDemand
GreatDemands
History
IntroductionHelp
Two other fields are not shown as they aren’t visible in the payload.
If you have such data, please kindly contribute.
Remaining fields: shownElements and shownHints
Map
MapsSplitShapeFileIds
Period
Players
Server
Settings
SlotSystem
Slots
SplitShapeId
Stats
Vehicle
VehicleFill

Enums

Filename
List of supported filenames in the dedicated-server-savegame endpoint
Format
This is only effective on DSS field in Endpoint struct
Mod
SeasonPeriod

Traits

Validation
Validate the data before doing something with it
Note: You must add your own validation code to use this!

Functions

calculate_economy_price
get_current_month